@@ -1,22 +1,24 @@
 import threading
 from spackle.customer import Customer
 from spackle.exceptions import SpackleException
-from spackle.stores import DynamoDBStore, MemoryStore
+from spackle.stores import DynamoDBStore, MemoryStore, FileStore
 from spackle.constants import FEATURE_TYPE_FLAG, FEATURE_TYPE_LIMIT
 
 api_key = None
 api_base = "https://api.spackle.so/v1"
-store_cls = DynamoDBStore
 schema_version = 1
 
-
 _thread = threading.local()
 
 
 def get_store():
-    if not hasattr(_thread, "adapter") or not isinstance(_thread.adapter, store_cls):
-        _thread.adapter = store_cls()
-    return _thread.adapter
+    if not hasattr(_thread, "store"):
+        _thread.store = DynamoDBStore()
+    return _thread.store
+
+
+def set_store(store):
+    _thread.store = store
 
 
 def bootstrap():
